==> mingw-w64-clang-aarch64-kirigami-6.3.0-2-any.pkg.tar.zst: clangarm64/lib/cmake/KF6Kirigami/KF6KirigamiTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF6KirigamiPrimitives" for configuration "Release"
set_property(TARGET KF6KirigamiPrimitives APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6KirigamiPrimitives PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libKirigamiPrimitives.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Core;Qt6::Quick;KF6::KirigamiPlatform"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libKirigamiPrimitives.dll"
  )

list(APPEND _cmake_import_check_targets KF6KirigamiPrimitives )
list(APPEND _cmake_import_check_files_for_KF6KirigamiPrimitives "${_IMPORT_PREFIX}/lib/libKirigamiPrimitives.dll.a" "${_IMPORT_PREFIX}/bin/libKirigamiPrimitives.dll" )

# Import target "KF6KirigamiDelegates" for configuration "Release"
set_property(TARGET KF6KirigamiDelegates APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6KirigamiDelegates PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libKirigamiDelegates.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Core"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libKirigamiDelegates.dll"
  )

list(APPEND _cmake_import_check_targets KF6KirigamiDelegates )
list(APPEND _cmake_import_check_files_for_KF6KirigamiDelegates "${_IMPORT_PREFIX}/lib/libKirigamiDelegates.dll.a" "${_IMPORT_PREFIX}/bin/libKirigamiDelegates.dll" )

# Import target "KF6KirigamiDialogs" for configuration "Release"
set_property(TARGET KF6KirigamiDialogs APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6KirigamiDialogs PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libKirigamiDialogs.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Core;Qt6::Quick;KF6::KirigamiPlatform"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libKirigamiDialogs.dll"
  )

list(APPEND _cmake_import_check_targets KF6KirigamiDialogs )
list(APPEND _cmake_import_check_files_for_KF6KirigamiDialogs "${_IMPORT_PREFIX}/lib/libKirigamiDialogs.dll.a" "${_IMPORT_PREFIX}/bin/libKirigamiDialogs.dll" )

# Import target "KF6KirigamiLayouts" for configuration "Release"
set_property(TARGET KF6KirigamiLayouts APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6KirigamiLayouts PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libKirigamiLayouts.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Core;Qt6::Quick;KF6::KirigamiPlatform"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libKirigamiLayouts.dll"
  )

list(APPEND _cmake_import_check_targets KF6KirigamiLayouts )
list(APPEND _cmake_import_check_files_for_KF6KirigamiLayouts "${_IMPORT_PREFIX}/lib/libKirigamiLayouts.dll.a" "${_IMPORT_PREFIX}/bin/libKirigamiLayouts.dll" )

# Import target "KF6Kirigami" for configuration "Release"
set_property(TARGET KF6Kirigami APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6Kirigami PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libKirigami.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Concurrent;KF6KirigamiDelegates;KF6KirigamiPrimitives;KF6KirigamiDialogs;KF6KirigamiLayouts"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libKirigami.dll"
  )

list(APPEND _cmake_import_check_targets KF6Kirigami )
list(APPEND _cmake_import_check_files_for_KF6Kirigami "${_IMPORT_PREFIX}/lib/libKirigami.dll.a" "${_IMPORT_PREFIX}/bin/libKirigami.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-clang-aarch64-kirigami-6.12.0-1-any.pkg.tar.zst: clangarm64/lib/cmake/KF6Kirigami/KF6KirigamiTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF6KirigamiPrimitives" for configuration "Release"
set_property(TARGET KF6KirigamiPrimitives APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6KirigamiPrimitives PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libKirigamiPrimitives.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Core;Qt6::Quick;KF6::KirigamiPlatform"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libKirigamiPrimitives.dll"
  )

list(APPEND _cmake_import_check_targets KF6KirigamiPrimitives )
list(APPEND _cmake_import_check_files_for_KF6KirigamiPrimitives "${_IMPORT_PREFIX}/lib/libKirigamiPrimitives.dll.a" "${_IMPORT_PREFIX}/bin/libKirigamiPrimitives.dll" )

# Import target "KF6KirigamiDelegates" for configuration "Release"
set_property(TARGET KF6KirigamiDelegates APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6KirigamiDelegates PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libKirigamiDelegates.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Core"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libKirigamiDelegates.dll"
  )

list(APPEND _cmake_import_check_targets KF6KirigamiDelegates )
list(APPEND _cmake_import_check_files_for_KF6KirigamiDelegates "${_IMPORT_PREFIX}/lib/libKirigamiDelegates.dll.a" "${_IMPORT_PREFIX}/bin/libKirigamiDelegates.dll" )

# Import target "KF6KirigamiDialogs" for configuration "Release"
set_property(TARGET KF6KirigamiDialogs APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6KirigamiDialogs PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libKirigamiDialogs.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Core;Qt6::Quick;KF6::KirigamiPlatform"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libKirigamiDialogs.dll"
  )

list(APPEND _cmake_import_check_targets KF6KirigamiDialogs )
list(APPEND _cmake_import_check_files_for_KF6KirigamiDialogs "${_IMPORT_PREFIX}/lib/libKirigamiDialogs.dll.a" "${_IMPORT_PREFIX}/bin/libKirigamiDialogs.dll" )

# Import target "KF6KirigamiLayouts" for configuration "Release"
set_property(TARGET KF6KirigamiLayouts APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6KirigamiLayouts PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libKirigamiLayouts.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Core;Qt6::Quick;Qt6::QuickControls2;KF6::KirigamiPlatform"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libKirigamiLayouts.dll"
  )

list(APPEND _cmake_import_check_targets KF6KirigamiLayouts )
list(APPEND _cmake_import_check_files_for_KF6KirigamiLayouts "${_IMPORT_PREFIX}/lib/libKirigamiLayouts.dll.a" "${_IMPORT_PREFIX}/bin/libKirigamiLayouts.dll" )

# Import target "KF6KirigamiPrivate" for configuration "Release"
set_property(TARGET KF6KirigamiPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6KirigamiPrivate PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libKirigamiPrivate.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Gui"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libKirigamiPrivate.dll"
  )

list(APPEND _cmake_import_check_targets KF6KirigamiPrivate )
list(APPEND _cmake_import_check_files_for_KF6KirigamiPrivate "${_IMPORT_PREFIX}/lib/libKirigamiPrivate.dll.a" "${_IMPORT_PREFIX}/bin/libKirigamiPrivate.dll" )

# Import target "KF6Kirigami" for configuration "Release"
set_property(TARGET KF6Kirigami APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6Kirigami PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libKirigami.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Concurrent;KF6KirigamiDelegates;KF6KirigamiPrimitives;KF6KirigamiDialogs;KF6KirigamiLayouts;KF6KirigamiPrivate"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libKirigami.dll"
  )

list(APPEND _cmake_import_check_targets KF6Kirigami )
list(APPEND _cmake_import_check_files_for_KF6Kirigami "${_IMPORT_PREFIX}/lib/libKirigami.dll.a" "${_IMPORT_PREFIX}/bin/libKirigami.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
